@@ -14,7 +14,7 @@ class QuoteClient(object):
         if isinstance(inter_service, Gateway):  # 暂时只支持网关接入
             self._inter_service = inter_service
             self._inter_service.set_default_service_name(SERVICE_MARKETDATA)
-            self._inter_service.set_protocol_head(chr(0x0f))
+            self._inter_service.set_protocol_head(chr(0x0c))
             self._inter_service.set_used_verbose_log(False)
             self._rpc_call = self._inter_service.gateway_call
         else:
